# Generated by Django 4.2.29 on 2026-03-27 18:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eds_auth', '0003_securitylog'),
    ]

    operations = [
        migrations.AlterField(
            model_name='securitylog',
            name='event_type',
            field=models.CharField(choices=[('auth_success', 'Successful authentication'), ('invalid_login', 'Invalid login'), ('invalid_password', 'Invalid password'), ('invalid_pem_key', 'Invalid PEM key'), ('invalid_signature', 'Invalid signature'), ('invalid_nonce', 'Invalid nonce'), ('certificate_missing', 'Certificate missing'), ('certificate_mismatch', 'Certificate mismatch'), ('certificate_revoked', 'Certificate revoked'), ('certificate_expired', 'Certificate expired'), ('rate_limit_attempt', 'Rate limit failed attempt'), ('rate_limit_locked', 'Rate limit lockout'), ('rate_limit_blocked', 'Rate limit blocked request'), ('backend_error', 'Authentication backend error')], db_index=True, max_length=50),
        ),
    ]
