# Generated by Django 4.2.29 on 2026-03-26 15:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_eds_auth", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="failedauthenticationattempt",
            name="attempt_type",
            field=models.CharField(
                choices=[
                    ("eds_signature", "EDS Signature Authentication"),
                    ("certificate_mismatch", "Certificate Mismatch"),
                    ("certificate_missing", "Certificate Missing"),
                    ("invalid_nonce", "Invalid Nonce"),
                    ("certificate_revoked", "Certificate Revoked"),
                    ("certificate_expired", "Certificate Expired"),
                    ("signature_invalid", "Signature Invalid"),
                ],
                max_length=50,
            ),
        ),
    ]
