# Generated by Django 4.2.29 on 2026-03-27 18:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eds_auth', '0004_alter_securitylog_event_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='failedauthenticationattempt',
            name='attempt_type',
            field=models.CharField(choices=[('eds_signature', 'EDS Signature Authentication'), ('user_not_found', 'User Not Found'), ('certificate_mismatch', 'Certificate Mismatch'), ('certificate_missing', 'Certificate Missing'), ('invalid_pem_key', 'Invalid PEM Key'), ('invalid_nonce', 'Invalid Nonce'), ('certificate_revoked', 'Certificate Revoked'), ('certificate_expired', 'Certificate Expired'), ('signature_invalid', 'Signature Invalid'), ('rate_limit_locked', 'Rate Limit Locked')], max_length=50),
        ),
    ]
